@@ -37,6 +37,7 @@ written in .ini files. The mapping between the Python setting and the [section/o
 """
 import os
 
+from df_config.guesses.djt import guess_djt_panels
 from django.utils.translation import gettext_lazy as _
 
 # ######################################################################################################################
@@ -60,6 +61,7 @@ from df_config.guesses.auth import (
     ldap_group_class,
     ldap_group_search,
     ldap_user_search,
+    CookieName,
 )
 from df_config.guesses.databases import (
     cache_redis_url,
@@ -90,6 +92,7 @@ from df_config.guesses.misc import (
     get_asgi_application,
     get_wsgi_application,
     use_sentry,
+    web_server, csp_connect,
 )
 from df_config.guesses.pipeline import (
     pipeline_compilers,
@@ -118,6 +121,7 @@ USE_ALL_AUTH = is_package_present("allauth")
 USE_WEBSOCKETS = is_package_present("df_websockets")
 USE_SITE = is_package_present("df_site")
 USE_WHITENOISE = is_package_present("whitenoise")
+USE_CSP = is_package_present("csp")
 
 # ######################################################################################################################
 #
@@ -130,6 +134,10 @@ ALLOWED_HOSTS = CallableSetting(allowed_hosts)
 CACHE_URL = CallableSetting(cache_redis_url)
 CACHES = CallableSetting(cache_setting)
 CSRF_COOKIE_DOMAIN = "{SERVER_NAME}"
+CSRF_COOKIE_HTTPONLY = False
+CSRF_COOKIE_NAME = CallableSetting(CookieName("csrftoken"))
+CSRF_COOKIE_SAMESITE = "Lax"
+CSRF_COOKIE_SECURE = SettingReference("USE_SSL")
 CSRF_TRUSTED_ORIGINS = ["{SERVER_NAME}", "{SERVER_NAME}:{SERVER_PORT}"]
 DATABASES = CallableSetting(databases)
 
@@ -142,9 +150,13 @@ DEVELOPMENT = True
 DEFAULT_FROM_EMAIL = "webmaster@{SERVER_NAME}"
 FILE_UPLOAD_TEMP_DIR = Directory("{LOCAL_PATH}/tmp-uploads")
 INSTALLED_APPS = CallableSetting(installed_apps)
+LANGUAGE_COOKIE_NAME = CallableSetting(CookieName("django_language"))
+LANGUAGE_COOKIE_DOMAIN = "{SERVER_NAME}"
+LANGUAGE_COOKIE_SAMESITE = "Lax"
+LANGUAGE_COOKIE_SECURE = SettingReference("USE_SSL")
 LOGGING = CallableSetting(log_configuration)
 MANAGERS = SettingReference("ADMINS")
-MEDIA_ROOT = Directory("{LOCAL_PATH}/media")
+MEDIA_ROOT = Directory("{LOCAL_PATH}/media", mode=0o755)
 MEDIA_URL = "/media/"
 MIDDLEWARE = CallableSetting(middlewares)
 
@@ -163,6 +175,11 @@ SECURE_SSL_REDIRECT = SettingReference("USE_SSL")
 SECURE_FRAME_DENY = SettingReference("USE_SSL")
 SERVER_EMAIL = "{ADMIN_EMAIL}"
 SESSION_COOKIE_AGE = 1209600
+SESSION_COOKIE_HTTPONLY = True
+SESSION_COOKIE_NAME = CallableSetting(CookieName("sessionid"))
+SESSION_COOKIE_DOMAIN = "{SERVER_NAME}"
+SESSION_COOKIE_SAMESITE = "Lax"
+SESSION_COOKIE_SECURE = SettingReference("USE_SSL")
 TEMPLATES = CallableSetting(template_setting)
 TEMPLATE_DEBUG = SettingReference("DEBUG")
 TEMPLATE_DIRS = ()
@@ -205,7 +222,7 @@ CSRF_COOKIE_SECURE = SettingReference("USE_SSL")
 SITE_ID = 1
 
 # django.contrib.staticfiles
-STATIC_ROOT = Directory("{LOCAL_PATH}/static")
+STATIC_ROOT = Directory("{LOCAL_PATH}/static", mode=0o755)
 STATIC_URL = "/static/"
 STATICFILES_STORAGE = CallableSetting(static_storage)
 STATICFILES_FINDERS = CallableSetting(static_finder)
@@ -238,7 +255,9 @@ USE_X_FORWARDED_FOR = CallableSetting(use_x_forwarded_for)  # X-Forwarded-For
 DF_FAKE_AUTHENTICATION_USERNAME = None
 DF_ALLOW_USER_CREATION = True
 
-DF_SERVER = "gunicorn"  # "gunicorn" or "daphne"
+DF_SERVER = CallableSetting(
+    web_server
+)  # must be "gunicorn" or "daphne" / used by the server command
 DF_REMOVED_DJANGO_COMMANDS = CallableSetting(excluded_django_commands)
 DF_ALLOW_LOCAL_USERS = True
 DF_CHECKED_REQUIREMENTS = CallableSetting(required_packages)
@@ -291,10 +310,17 @@ PIPELINE_CSS = {
 }
 PIPELINE_ENABLED = CallableSetting(pipeline_enabled)
 PIPELINE_JS = {
-    "django.admin": {"source_filenames": [], "output_filename": "js/django-admin.js"},
+    "django.admin": {
+        "source_filenames": [],
+        "output_filename": "js/django-admin.js",
+        "integrity": "sha384",
+        "crossorigin": "anonymous",
+    },
     "default": {
         "source_filenames": [ExpandIterable("DF_JS")],
         "output_filename": "js/default.js",
+        "integrity": "sha384",
+        "crossorigin": "anonymous",
     },
 }
 LIVE_SCRIPT_BINARY = "lsc"
@@ -329,20 +355,7 @@ ACCOUNT_ADAPTER = "df_config.apps.allauth.AccountAdapter"
 # Django-Debug-Toolbar
 DEBUG_TOOLBAR_CONFIG = {"JQUERY_URL": "{STATIC_URL}vendor/jquery/dist/jquery.min.js"}
 DEBUG_TOOLBAR_PATCH_SETTINGS = False
-DEBUG_TOOLBAR_PANELS = [
-    "debug_toolbar.panels.versions.VersionsPanel",
-    "debug_toolbar.panels.timer.TimerPanel",
-    "debug_toolbar.panels.settings.SettingsPanel",
-    "debug_toolbar.panels.profiling.ProfilingPanel",
-    "debug_toolbar.panels.headers.HeadersPanel",
-    "debug_toolbar.panels.request.RequestPanel",
-    "debug_toolbar.panels.sql.SQLPanel",
-    "debug_toolbar.panels.templates.TemplatesPanel",
-    "debug_toolbar.panels.staticfiles.StaticFilesPanel",
-    "debug_toolbar.panels.cache.CachePanel",
-    "debug_toolbar.panels.signals.SignalsPanel",
-    "debug_toolbar.panels.redirects.RedirectsPanel",
-]
+DEBUG_TOOLBAR_PANELS = CallableSetting(guess_djt_panels)
 INTERNAL_IPS = ("127.0.0.1", "::1", "localhost")
 
 # django-auth-ldap
@@ -376,10 +389,6 @@ AUTH_LDAP_FIND_GROUP_PERMS = False
 AUTH_LDAP_GROUP_SEARCH = CallableSetting(ldap_group_search)
 AUTH_LDAP_GROUP_SEARCH_BASE = "ou=groups,dc=example,dc=com"
 AUTH_LDAP_AUTHORIZE_ALL_USERS = True
-# https://bitbucket.org/illocution/django-auth-ldap/pull-requests/29/kerberos-bind-method-to-provide-multi/diff
-# KRB5_CCACHE = None
-# KRB5_KEYTAB = None
-# KRB5_PRINCIPAL = None
 
 # django-cors-headers
 CORS_ORIGIN_WHITELIST = ("{SERVER_NAME}", "{SERVER_NAME}:{SERVER_PORT}")
@@ -405,6 +414,10 @@ SESSION_REDIS = CallableSetting(session_redis_dict)
 USE_DJANGO_JQUERY = True
 JQUERY_URL = False
 
+# django-csp
+CSP_CONNECT_SRC = CallableSetting(csp_connect)
+CSP_BLOCK_ALL_MIXED_CONTENT = True
+
 # ######################################################################################################################
 #
 # settings that should be customized for each project
@@ -548,3 +561,4 @@ CELERY_PROCESSES = 4
 
 # sentry.io
 USE_SENTRY = CallableSetting(use_sentry)
+SENTRY_DSN = None
