@@ -100,7 +100,7 @@ class InstalledApps:
     def __call__(self, settings_dict):
         apps = self.default_apps
         if settings_dict["SESSION_ENGINE"] == "django.contrib.sessions.backends.db":
-            apps += ['django.contrib.sessions']
+            apps += ["django.contrib.sessions"]
         apps += self.process_django_allauth(settings_dict)
         apps += self.process_third_parties(settings_dict)
         apps += self.base_django_apps
@@ -181,7 +181,7 @@ class Middlewares:
         [
             ("USE_WHITENOISE", "whitenoise.middleware.WhiteNoiseMiddleware"),
             ("USE_WEBSOCKETS", "df_websockets.middleware.WebsocketMiddleware"),
-            ("USE_DEBUG_TOOLBAR", "debug_toolbar.middleware.DebugToolbarMiddleware"),
+            ("USE_CSP", "csp.middleware.CSPMiddleware"),
         ]
     )
     required_settings = ["DF_MIDDLEWARE"] + list(common_third_parties)
@@ -192,7 +192,8 @@ class Middlewares:
         mw_list += self.base_django_middlewares
         mw_list.append(ExpandIterable("DF_MIDDLEWARE"))
         mw_list += self.process_third_parties(settings_dict)
-
+        if settings_dict["USE_DEBUG_TOOLBAR"]:
+            mw_list.insert(0, "debug_toolbar.middleware.DebugToolbarMiddleware")
         if self.use_cache_middleware:
             mw_list.insert(0, "django.middleware.cache.UpdateCacheMiddleware")
             mw_list.append("django.middleware.cache.FetchFromCacheMiddleware")
