@@ -172,7 +172,7 @@ class RedisSmartSetting:
             # noinspection PyUnresolvedReferences
             result = {
                 "BACKEND": "channels_redis.core.RedisChannelLayer",
-                "CONFIG": {"hosts": [config]},
+                "CONFIG": {"hosts": [config], "capacity": 5000, "expiry": 10,},
             }
             return result
         elif self.fmt == "dict":
