@@ -18,18 +18,17 @@ import logging
 import logging.handlers
 import os
 import re
-import sys
-import time
 import warnings
 from traceback import extract_stack
 from urllib.parse import urlparse
 
+import sys
+import time
 from django.core.checks.messages import Warning
 from django.core.management import color_style
 from django.utils.log import AdminEmailHandler as BaseAdminEmailHandler
 
 from df_config.checks import settings_check_results
-from df_config.utils import is_package_present
 
 
 class ColorizedFormatter(logging.Formatter):
@@ -179,7 +178,6 @@ class LogConfiguration:
     *  `SERVER_NAME`: the public name of the server (like "www.example.com")
     *  `SERVER_PORT`: the public port (probably 80 or 443)
     * `LOG_EXCLUDED_COMMANDS`: Django commands that do not write logs
-    * `RAVEN_DSN`: `Sentry <https://sentry.io>`_ DSN (URL embedding login and password)
     """
 
     required_settings = [
@@ -191,7 +189,6 @@ class LogConfiguration:
         "SERVER_NAME",
         "SERVER_PORT",
         "LOG_EXCLUDED_COMMANDS",
-        "RAVEN_DSN",
         "LOG_LEVEL",
     ]
     # for loggers that only show INFO in debug mode, or WARN in INFO, and so on:
@@ -289,15 +286,6 @@ class LogConfiguration:
 
         has_handler = False
 
-        if settings_dict["RAVEN_DSN"] and is_package_present("raven"):
-            self.handlers["sentry"] = {
-                "level": "ERROR",
-                "class": "raven.contrib.django.raven_compat.handlers.SentryHandler",
-                "tags": {"application": self.log_suffix},
-            }
-            self.root["handlers"].append("sentry")
-            has_handler = True
-
         if self.log_directory and self.log_suffix:
             self.add_handler("ROOT", "root", level=log_level)
             for logger in self.access_loggers:
