@@ -15,7 +15,7 @@
 # ##############################################################################
 import os
 import re
-from typing import Dict
+from typing import Dict, List
 from urllib.parse import urlparse
 
 from django.core.checks import Warning
@@ -102,7 +102,7 @@ allowed_hosts.required_settings = ["SERVER_NAME", "LISTEN_ADDRESS"]
 
 def secure_hsts_seconds(settings_dict):
     if settings_dict["USE_SSL"]:
-        return 86400
+        return 86400 * 31 * 12
     return 0
 
 
@@ -373,3 +373,34 @@ def use_sentry(settings_dict: Dict) -> bool:
 
 
 use_sentry.required_settings = ["SENTRY_DSN", "USE_CELERY", "DEBUG"]
+
+
+# noinspection PyUnusedLocal
+def web_server(settings_dict) -> str:
+    try:
+        # noinspection PyPackageRequirements
+        import daphne
+
+        return "daphne"
+    except ImportError:
+        return "gunicorn"
+
+
+web_server.required_settings = []
+
+
+def csp_connect(settings_dict) -> List[str]:
+    values = ["'self'"]
+    if settings_dict["USE_SSL"] and settings_dict["USE_WEBSOCKETS"]:
+        values.append("wss://%(SERVER_NAME)s:%(SERVER_PORT)s" % settings_dict)
+    elif settings_dict["USE_WEBSOCKETS"]:
+        values.append("ws://%(SERVER_NAME)s:%(SERVER_PORT)s" % settings_dict)
+    return values
+
+
+web_server.required_settings = [
+    "USE_SSL",
+    "SERVER_NAME",
+    "USE_WEBSOCKETS",
+    "SERVER_PORT",
+]
