@@ -13,14 +13,15 @@ If DjangoDebugToolbar is present, then its URL is also registered.
 
 """
 
-from df_config.utils import get_view_from_string
 from django.conf import settings
-from django.conf.urls import include, url
-from django.urls import path
+from django.conf.urls import include
+from django.urls import path, re_path
 from django.utils.module_loading import autodiscover_modules, import_string
 from django.views.i18n import JavaScriptCatalog
 from django.views.static import serve
 
+from df_config.utils import get_view_from_string
+
 
 def common_static_urls():
     values = (
@@ -68,6 +69,7 @@ if settings.DF_URL_CONF:
 if settings.USE_ALL_AUTH:
     # noinspection PyUnresolvedReferences
     from allauth.account.views import login
+
     urlpatterns += [
         path("admin/login/", login),
         path("accounts/", include("allauth.urls")),
@@ -86,6 +88,7 @@ if settings.DF_ADMIN_SITE:
 if settings.DEBUG and settings.USE_DEBUG_TOOLBAR:
     # noinspection PyPackageRequirements,PyUnresolvedReferences
     import debug_toolbar
+
     urlpatterns += [path("__debug__/", include(debug_toolbar.urls))]
 if settings.DF_INDEX_VIEW:
     urlpatterns += [
@@ -99,4 +102,4 @@ if settings.USE_WEBSOCKETS:
 url_prefix = settings.URL_PREFIX[1:]
 
 if url_prefix:
-    urlpatterns = [url("^" + url_prefix, include(urlpatterns))]
+    urlpatterns = [re_path("^" + url_prefix, include(urlpatterns))]
